@@ -121,9 +121,12 @@ class Toolchain:
                 else:
                     print(f"ERROR: operating system not supported")
 
-                # Also remove the directory in .simpleiot
+                # Also remove the directory in .simpleiot if it still exists
                 #
-                shutil.rmtree(install_dir)
+                if os.path.exists(install_dir):
+                    shutil.rmtree(install_dir)
+
+                print("Done.")
             else:
                 print(f"ERROR: unable to uninstall toolchain for specified device")
                 exit(1)
